# Win32API 参考手册（勇芳软件工作室汉化）

## 下载

### Docker

```
docker pull apachecn0/win32api-cankaoshouce-yongfang-ruanjian-gongzuoshi-hanhua
docker run -tid -p <port>:80 apachecn0/win32api-cankaoshouce-yongfang-ruanjian-gongzuoshi-hanhua
# 访问 http://localhost:{port} 查看文档
```

### PYPI

```
pip install win32api-cankaoshouce-yongfang-ruanjian-gongzuoshi-hanhua
win32api-cankaoshouce-yongfang-ruanjian-gongzuoshi-hanhua <port>
# 访问 http://localhost:{port} 查看文档
```

### NPM

```
npm install -g winsanerapi-cankaoshouce-yongfang-ruanjian-gongzuoshi-hanhua
winsanerapi-cankaoshouce-yongfang-ruanjian-gongzuoshi-hanhua <port>
# 访问 http://localhost:{port} 查看文档
```